---
title: item-09 Infer return type object
---

*Return value* is often just *object* in the documentation.
It can usually be inferred from context.
E.g. *Chart.SeriesCollection* returns a *SeriesCollection*.
https://learn.microsoft.com/en-gb/office/vba/api/excel.chart.seriescollection

Fix by updating the documentation or inferring the class.
